@@ -1,10 +1,8 @@
 # -*- coding: utf-8 -*-
-import sys
 import re
-import semver
-
-from halo import Halo
+import sys
 
+from suite_py.commands.release import _parse_available_countries
 from suite_py.lib import logger
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
@@ -12,8 +10,8 @@ from suite_py.lib.handler.captainhook_handler import CaptainHook
 from suite_py.lib.handler.drone_handler import DroneHandler
 from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler.github_handler import GithubHandler
+from suite_py.lib.handler.version_handler import DEFAULT_VERSION, VersionHandler
 from suite_py.lib.handler.youtrack_handler import YoutrackHandler
-from suite_py.commands.release import _parse_available_countries
 
 
 class Deploy:
@@ -28,6 +26,7 @@ class Deploy:
         self._git = GitHandler(project, config)
         self._drone = DroneHandler(config, tokens, repo=project)
         self._countries = _parse_available_countries(self._drone)
+        self._version = VersionHandler(self._repo, self._git, self._github)
 
     def run(self):
         self._stop_if_prod_locked()
@@ -40,15 +39,10 @@ class Deploy:
             )
             sys.exit(1)
 
-        tags = self._repo.get_tags()
-        tag = git.get_last_tag_number(tags)
-        latest_release = self._get_release(tag)
+        current_version = self._version.get_latest_version()
 
-        current_version = latest_release.tag_name if latest_release else tag
-
-        if current_version:
+        if current_version != DEFAULT_VERSION:
             logger.info(f"The current release is {current_version}")
-            versions = _bump_versions(current_version)
             commits = self._github.get_commits_since_release(
                 self._repo, current_version
             )
@@ -64,23 +58,18 @@ class Deploy:
             if not prompt_utils.ask_confirm("Do you want to continue?"):
                 sys.exit()
 
-            new_version = prompt_utils.ask_choices(
-                "Select version:",
-                [
-                    {"name": f"Patch {versions['patch']}", "value": versions["patch"]},
-                    {"name": f"Minor {versions['minor']}", "value": versions["minor"]},
-                    {"name": f"Major {versions['major']}", "value": versions["major"]},
-                ],
-            )
+            new_version = self._version.select_new_version(current_version)
 
         else:
             # Se non viene trovata la release e non ci sono tag, viene saltato il check delle migrations e l'update delle card su youtrack
-            logger.warning("No tags found, I'm about to push the tag 0.1.0")
+            logger.warning(
+                f"No tags found, I'm about to push the tag {DEFAULT_VERSION}"
+            )
             if not prompt_utils.ask_confirm(
                 "Are you sure you want to continue?", default=False
             ):
                 sys.exit()
-            new_version = "0.1.0"
+            new_version = DEFAULT_VERSION
             message = f"First release with tag {new_version}"
 
         self._create_release(new_version, message)
@@ -99,13 +88,6 @@ class Deploy:
             )
             sys.exit(-1)
 
-    def _get_release(self, tag):
-        with Halo(text="Loading...", spinner="dots", color="magenta"):
-            latest_release = self._github.get_latest_release_if_exists(self._repo)
-            if latest_release and latest_release.title == tag:
-                return latest_release
-        return None
-
     def _create_release(self, new_version, message):
         new_release = self._repo.create_git_release(
             new_version,
@@ -180,14 +162,6 @@ class Deploy:
         return repos_status
 
 
-def _bump_versions(current):
-    return {
-        "patch": semver.bump_patch(current),
-        "minor": semver.bump_minor(current),
-        "major": semver.bump_major(current),
-    }
-
-
 def _check_migrations_deploy(commits):
     if not commits:
         logger.error("ERROR: no commit found")
